@@ -17,7 +17,7 @@ class Course:
         self.name = name
         self.code = code
         self.workflow_state = workflow_state
-        self.syllabus = syllabus
+        self.syllabus = helpers.filter_canvas_html(syllabus)
         if self.syllabus is None:
             self.syllabus = ""
 
@@ -66,11 +66,26 @@ def get_id_from_url(course_url):
         print(f"Invalid course url f{course_url}")
         sys.exit(1)
 
+def match_courses(db, terms):
+    courses = []
+    for course_ in terms:
+        courses += match_course(db, course_)
+    for course_ in courses:
+        print(course_)
+    # TODO: is it worth confirming? maybe only confirm if the length of the
+    # returned courses differs from the length of the search terms list
+    response = input("Found these courses. Correct? (y/n) ")
+    if response.lower() == 'n':
+        print("Please refine your search terms")
+        sys.exit()
+    return courses
+
 def match_course(db, search):
     # assume searching by canvas id first
-    results = find(db, search)
-    if len(results) > 0:
-        return results
+    if search.isdigit():
+        results = find(db, int(search))
+        if len(results) > 0:
+            return results
 
     # if we didn't find the course, user might have given the section number
     # so search for it by name
@@ -79,7 +94,7 @@ def match_course(db, search):
         test_func = lambda field: term in field
         CourseQ = tinydb.Query()
         courses = db.table(COURSES_TABLE)
-        results += [build(c) for c in courses.search(CourseQ.name.test(test_func))]
+        results += [build(c) for c in courses.search(CourseQ.code.test(test_func))]
     return results
 
 def pull(db, course_id):
@@ -89,10 +104,13 @@ def pull(db, course_id):
     return Course(response["id"], response["name"], response["course_code"],
             response["workflow_state"], response["syllabus_body"])
 
-def push_syllabus(db, courses=[]):
+def push_syllabus(db, course_id, dry_run):
     with open("syllabus.md") as f:
-        c = {"course": {"syllabus_body": helpers.md2html(f.read())}}
-    if not courses:
-        courses = find_all(db)
-    for course_ in courses:
-        helpers.put(COURSE_PATH.format(course_.canvas_id), c)
+        c = {"course": {
+            "syllabus_body": helpers.md2html(f.read()),
+            "apply_assignment_group_weights": True
+            }}
+        if dry_run:
+            print(f"DRYRUN - pushing syllabus")
+        else:
+            helpers.put(COURSE_PATH.format(course_id), c)
